@@ -4,7 +4,7 @@ Main interface for resourcegroupstaggingapi service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_resourcegroupstaggingapi import (
         Client,
         GetComplianceSummaryPaginator,
@@ -14,10 +14,8 @@ Usage::
         ResourceGroupsTaggingAPIClient,
     )
 
-    session = boto3.Session()
-
-    client: ResourceGroupsTaggingAPIClient = boto3.client("resourcegroupstaggingapi")
-    session_client: ResourceGroupsTaggingAPIClient = session.client("resourcegroupstaggingapi")
+    session = Session()
+    client: ResourceGroupsTaggingAPIClient = session.client("resourcegroupstaggingapi")
 
     get_compliance_summary_paginator: GetComplianceSummaryPaginator = client.get_paginator("get_compliance_summary")
     get_resources_paginator: GetResourcesPaginator = client.get_paginator("get_resources")
@@ -25,8 +23,8 @@ Usage::
     get_tag_values_paginator: GetTagValuesPaginator = client.get_paginator("get_tag_values")
     ```
 """
-from mypy_boto3_resourcegroupstaggingapi.client import ResourceGroupsTaggingAPIClient
-from mypy_boto3_resourcegroupstaggingapi.paginator import (
+from .client import ResourceGroupsTaggingAPIClient
+from .paginator import (
     GetComplianceSummaryPaginator,
     GetResourcesPaginator,
     GetTagKeysPaginator,
